{% extends "../page_layout.html" %} {% block title %}History | Unmanic{% end %} {% block page %}history{% end %} {% block head %} {#Emptyness and sadness#} {% end %} {% block page_plugin_styles %} {# START DATATABLES #} {# END DATATABLES #} {% end %} {% block page_plugins %} {# START DATATABLES #}
{# END DATATABLES #} {% end %} {% block vendor_scripts %} {# START HIGHCHARTS #}
{# END HIGHCHARTS #} {% end %} {% block page_theme_scripts %} {# START PAGE COMPONENTS #}
{# END PAGE COMPONENTS #} {% end %} {% block content %} {# Remove filters for now #} {#
All ({{ data['total_count'] }}) Success ({{ data['success_count'] }}) Failure ({{ data['failed_count'] }})
#}
Completed Tasks
{% include "history-completed-tasks-list.html" %}
{% end %}